Welcome to networking-odl's documentation!
==========================================

.. include:: ../../README.rst

General Documentation
---------------------

.. toctree::
   :maxdepth: 1

   installation
   reference_architecture
   usage
   contributing

Developer Docs
--------------

.. toctree::
   :maxdepth: 1

   devref/index
   specs


Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

